@@ -1,4 +1,4 @@
-version = "0.1.1"
+version = "0.3.1"
 language = "en-US"
 timeout = 15
 user = None
@@ -8,6 +8,9 @@ from starkcore import Project, Organization, key, error
 from . import event
 from .event.__event import Event
 
+from . import brcodepreview
+from .brcodepreview.__brcodepreview import BrcodePreview
+
 from . import pixrequest
 from .pixrequest.__pixrequest import PixRequest
 
@@ -38,15 +41,21 @@ from .pixinfraction.__pixinfraction import PixInfraction
 from . import pixchargeback
 from .pixchargeback.__pixchargeback import PixChargeback
 
-from . import issuingauthorization
-from .issuingauthorization.__issuingauthorization import IssuingAuthorization
-
 from . import issuingbalance
 from .issuingbalance.__issuingbalance import IssuingBalance
 
 from . import creditnote
 from .creditnote.__creditnote import CreditNote
 
+from . import creditpreview
+from .creditpreview.__creditpreview import CreditPreview
+
+from . import dynamicbrcode
+from .dynamicbrcode.__dynamicbrcode import DynamicBrcode
+
+from . import staticbrcode
+from .staticbrcode.__staticbrcode import StaticBrcode
+
 from . import issuingtransaction
 from .issuingtransaction.__issuingtransaction import IssuingTransaction
 
@@ -65,11 +74,20 @@ from .issuinginvoice.__issuinginvoice import IssuingInvoice
 from . import issuingwithdrawal
 from .issuingwithdrawal.__issuingwithdrawal import IssuingWithdrawal
 
-from . import issuingbin
-from .issuingbin.__issuingbin import IssuingBin
+from . import issuingproduct
+from .issuingproduct.__issuingproduct import IssuingProduct
 
-from . import __issuingrule
-from .__issuingrule.__issuingrule import IssuingRule
+from . import issuingrule
+from .issuingrule.__issuingrule import IssuingRule
+
+from . import merchantcategory
+from .merchantcategory.__merchantcategory import MerchantCategory
+
+from . import merchantcountry
+from .merchantcountry.__merchantcountry import MerchantCountry
+
+from . import cardmethod
+from .cardmethod.__cardmethod import CardMethod
 
 from . import webhook
 from .webhook.__webhook import Webhook
