@@ -17,36 +17,38 @@ class PixChargeback(Resource):
     - reason [string]: reason why the reversal was requested. Options: "fraud", "flaw", "reversalChargeback"
     ## Parameters (optional):
     - description [string, default None]: description for the PixChargeback.
+    - tags [list of strings, default []]: list of strings for tagging. ex: ["travel", "food"]
     ## Attributes (return-only):
     - id [string]: unique id returned when the PixChargeback is created. ex: "5656565656565656"
     - analysis [string]: analysis that led to the result.
-    - bacen_id [string]: central bank's unique UUID that identifies the PixChargeback.
     - sender_bank_code [string]: bank_code of the Pix participant that created the PixChargeback. ex: "20018183"
     - receiver_bank_code [string]: bank_code of the Pix participant that received the PixChargeback. ex: "20018183"
     - rejection_reason [string]: reason for the rejection of the Pix chargeback. Options: "noBalance", "accountClosed", "unableToReverse"
-    - reversal_reference_id [string]: return id of the reversal transaction. ex: "D20018183202202030109X3OoBHG74wo".
+    - reversal_reference_id [string]: return_id or end_to_end_id of the reversal transaction. ex: "D20018183202202030109X3OoBHG74wo"
     - result [string]: result after the analysis of the PixChargeback by the receiving party. Options: "rejected", "accepted", "partiallyAccepted"
-    - status [string]: current PixChargeback status. Options: "created", "failed", "delivered", "closed", "canceled".
+    - flow [string]: direction of the Pix Chargeback. Options: "in" for received chargebacks, "out" for chargebacks you requested
+    - status [string]: current PixChargeback status. Options: "created", "failed", "delivered", "closed", "canceled"
     - created [datetime.datetime]: creation datetime for the PixChargeback. ex: datetime.datetime(2020, 3, 10, 10, 30, 0, 0)
     - updated [datetime.datetime]: latest update datetime for the PixChargeback. ex: datetime.datetime(2020, 3, 10, 10, 30, 0, 0)
     """
 
-    def __init__(self,  amount, reference_id, reason, description=None, id=None, analysis=None, bacen_id=None,
+    def __init__(self,  amount, reference_id, reason, description=None, tags=None, id=None, analysis=None,
                  sender_bank_code=None, receiver_bank_code=None, rejection_reason=None, reversal_reference_id=None,
-                 result=None, status=None, created=None, updated=None):
+                 result=None, flow=None, status=None, created=None, updated=None):
         Resource.__init__(self, id=id)
 
         self.amount = amount
         self.reference_id = reference_id
         self.reason = reason
         self.description = description
+        self.tags = tags
         self.analysis = analysis
-        self.bacen_id = bacen_id
         self.sender_bank_code = sender_bank_code
         self.receiver_bank_code = receiver_bank_code
         self.rejection_reason = rejection_reason
         self.reversal_reference_id = reversal_reference_id
         self.result = result
+        self.flow = flow
         self.status = status
         self.created = created
         self.updated = updated
@@ -61,7 +63,7 @@ def create(chargebacks, user=None):
     ## Parameters (optional):
     - chargebacks [list of PixChargeback]: list of PixChargeback objects to be created in the API.
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - list of PixChargeback objects with updated attributes
     """
@@ -72,9 +74,9 @@ def get(id, user=None):
     """# Retrieve a PixChargeback object
     Retrieve the PixChargeback object linked to your Workspace in the Stark Infra API using its id.
     ## Parameters (required):
-    - id [string]: object unique id. ex: "5656565656565656".
+    - id [string]: object unique id. ex: "5656565656565656"
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - PixChargeback object that corresponds to the given id.
     """
@@ -82,16 +84,18 @@ def get(id, user=None):
     return rest.get_id(id=id, resource=_resource, user=user)
 
 
-def query(limit=None, after=None, before=None, status=None, ids=None, user=None):
+def query(limit=None, after=None, before=None, status=None, ids=None, flow=None, tags=None, user=None):
     """# Retrieve PixChargebacks
-    Receive a generator of PixChargebacks objects previously created in the Stark Infra API
+    Receive a generator of PixChargeback objects previously created in the Stark Infra API
     ## Parameters (optional):
     - limit [integer, default None]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
     - after [datetime.date or string, default None]: date filter for objects created after a specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "failed", "delivered", "closed", "canceled"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - flow [string, default None]: direction of the Pix Chargeback. Options: "in" for received chargebacks, "out" for chargebacks you requested
+    - tags [list of strings, default None]: filter for tags of retrieved objects. ex: ["travel", "food"]
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - generator of PixChargeback objects with updated attributes
     """
@@ -103,13 +107,15 @@ def query(limit=None, after=None, before=None, status=None, ids=None, user=None)
         before=check_date(before),
         status=status,
         ids=ids,
+        flow=flow,
+        tags=tags,
         user=user,
     )
 
 
-def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None, user=None):
+def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None, flow=None, tags=None, user=None):
     """# Retrieve PixChargebacks
-    Receive a generator of PixChargebacks objects previously created in the Stark Infra API
+    Receive a generator of PixChargeback objects previously created in the Stark Infra API
     ## Parameters (optional):
     - cursor [string, default None]: cursor returned on the previous page function call.
     - limit [integer, default 100]: maximum number of objects to be retrieved. Max = 100. ex: 35
@@ -117,7 +123,9 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "failed", "delivered", "closed", "canceled"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - flow [string, default None]: direction of the Pix Chargeback. Options: "in" for received chargebacks, "out" for chargebacks you requested
+    - tags [list of strings, default None]: filter for tags of retrieved objects. ex: ["travel", "food"]
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - cursor to retrieve the next page of PixChargeback objects
     - generator of PixChargeback objects with updated attributes
@@ -130,6 +138,8 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None
         before=check_date(before),
         status=status,
         ids=ids,
+        flow=flow,
+        tags=tags,
         user=user,
     )
 
@@ -139,7 +149,7 @@ def update(id, result, rejection_reason=None, reversal_reference_id=None, analys
     Respond to a received PixChargeback.
     ## Parameters (required):
     - id [string]: PixChargeback id. ex: '5656565656565656'
-    - result [string]: result after the analysis of the PixChargeback. Options: "rejected", "accepted", "partiallyAccepted".
+    - result [string]: result after the analysis of the PixChargeback. Options: "rejected", "accepted", "partiallyAccepted"
     ## Parameters (conditionally required):
     - rejection_reason [string, default None]: if the PixChargeback is rejected a reason is required. Options: "noBalance", "accountClosed", "unableToReverse",
     - reversal_reference_id [string, default None]: return_id of the reversal transaction. ex: "D20018183202201201450u34sDGd19lz"
@@ -163,7 +173,7 @@ def cancel(id, user=None):
     ## Parameters (required):
     - id [string]: object unique id. ex: "5656565656565656"
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - canceled PixChargeback object
     """
