@@ -1,5 +1,7 @@
+from json import dumps
 from ..utils import rest
 from ..utils.parse import parse_and_verify
+from starkcore.utils.api import api_json
 from starkcore.utils.resource import Resource
 from starkcore.utils.checks import check_datetime, check_date
 
@@ -26,16 +28,17 @@ class PixRequest(Resource):
     - receiver_branch_code [string]: receiver's bank account branch code. Use '-' in case there is a verifier digit. ex: "1357-9"
     - receiver_account_type [string]: receiver's bank account type. ex: "checking", "savings", "salary" or "payment"
     - end_to_end_id [string]: central bank's unique transaction ID. ex: "E79457883202101262140HHX553UPqeq"
+    ## Parameters (conditionally-required):
+    - cashier_type [string]: Cashier's type. Required if the cash_amount is different from 0. Options: "merchant", "participant" and "other"
+    - cashier_bank_code [string]: Cashier's bank code. Required if the cash_amount is different from 0. ex: "20018183"
     ## Parameters (optional):
+    - cash_amount [integer]: Amount to be withdrawn from the cashier in cents. ex: 1000 (= R$ 10.00)
     - receiver_key_id [string, default None]: receiver's dict key. ex: "20.018.183/0001-80"
     - description [string, default None]: optional description to override default description to be shown in the bank statement. ex: "Payment for service #1234"
     - reconciliation_id [string, default None]: Reconciliation ID linked to this payment. ex: "b77f5236-7ab9-4487-9f95-66ee6eaf1781"
     - initiator_tax_id [string, default None]: Payment initiator's tax id (CPF/CNPJ). ex: "01234567890" or "20.018.183/0001-80"
-    - cash_amount [integer, default None]: Amount to be withdrawal from the cashier in cents. ex: 1000 (= R$ 10.00)
-    - cashier_bank_code [string, default None]: Cashier's bank code. ex: "00000000"
-    - cashier_type [string, default None]: Cashier's type. ex: [merchant, other, participant]
-    - tags [list of strings, default None]: list of strings for reference when searching for PixRequests. ex: ["employees", "monthly"]
-    - method [string, default None]: execution  method for thr creation of the Pix. ex: "manual", "payerQrcode", "dynamicQrcode".
+    - tags [list of strings, default []]: list of strings for reference when searching for PixRequests. ex: ["employees", "monthly"]
+    - method [string, default None]: execution  method for thr creation of the Pix. ex: "manual", "payerQrcode", "dynamicQrcode"
     ## Attributes (return-only):
     - id [string]: unique id returned when the PixRequest is created. ex: "5656565656565656"
     - fee [integer]: fee charged when PixRequest is paid. ex: 200 (= R$ 2.00)
@@ -49,8 +52,8 @@ class PixRequest(Resource):
     def __init__(self, amount, external_id, sender_name, sender_tax_id, sender_branch_code,
                  sender_account_number, sender_account_type, receiver_name, receiver_tax_id, receiver_bank_code,
                  receiver_account_number, receiver_branch_code, receiver_account_type, end_to_end_id,
-                 receiver_key_id=None, description=None, reconciliation_id=None, initiator_tax_id=None,
-                 cash_amount=None, cashier_bank_code=None, cashier_type=None, tags=None, method=None, id=None, fee=None,
+                 cashier_type=None, cashier_bank_code=None, cash_amount=None, receiver_key_id=None, description=None, 
+                 reconciliation_id=None, initiator_tax_id=None, tags=None, method=None, id=None, fee=None,
                  status=None, flow=None, sender_bank_code=None, created=None, updated=None):
         Resource.__init__(self, id=id)
 
@@ -68,13 +71,13 @@ class PixRequest(Resource):
         self.receiver_branch_code = receiver_branch_code
         self.receiver_account_type = receiver_account_type
         self.end_to_end_id = end_to_end_id
+        self.cashier_type = cashier_type
+        self.cashier_bank_code = cashier_bank_code
+        self.cash_amount = cash_amount
         self.receiver_key_id = receiver_key_id
         self.description = description
         self.reconciliation_id = reconciliation_id
         self.initiator_tax_id = initiator_tax_id
-        self.cash_amount = cash_amount
-        self.cashier_bank_code = cashier_bank_code
-        self.cashier_type = cashier_type
         self.tags = tags
         self.method = method
         self.fee = fee
@@ -94,7 +97,7 @@ def create(requests, user=None):
     ## Parameters (required):
     - requests [list of PixRequest objects]: list of PixRequest objects to be created in the API
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - list of PixRequest objects with updated attributes
     """
@@ -107,15 +110,15 @@ def get(id, user=None):
     ## Parameters (required):
     - id [string]: object unique id. ex: "5656565656565656"
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - PixRequest object with updated attributes
     """
     return rest.get_id(resource=_resource, id=id, user=user)
 
 
-def query(limit=None, after=None, before=None, status=None, tags=None, ids=None, end_to_end_ids=None,
-          external_ids=None, user=None):
+def query(limit=None, after=None, before=None, status=None, ids=None, end_to_end_ids=None,
+          external_ids=None, tags=None, user=None):
     """# Retrieve PixRequests
     Receive a generator of PixRequest objects previously created in the Stark Infra API
     ## Parameters (optional):
@@ -123,11 +126,11 @@ def query(limit=None, after=None, before=None, status=None, tags=None, ids=None,
     - after [datetime.date or string, default None]: date filter for objects created after a specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "processing", "success", "failed"]
-    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - end_to_end_ids [list of strings, default None]: central bank's unique transaction IDs. ex: ["E79457883202101262140HHX553UPqeq", "E79457883202101262140HHX553UPxzx"]
     - external_ids [list of strings, default None]: url safe strings that must be unique among all your PixRequests. Duplicated external IDs will cause failures. By default, this parameter will block any PixRequests that repeats amount and receiver information on the same date. ex: ["my-internal-id-123456", "my-internal-id-654321"]
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - generator of PixRequest objects with updated attributes
     """
@@ -137,16 +140,16 @@ def query(limit=None, after=None, before=None, status=None, tags=None, ids=None,
         after=check_date(after),
         before=check_date(before),
         status=status,
-        tags=tags,
         ids=ids,
         end_to_end_ids=end_to_end_ids,
         external_ids=external_ids,
+        tags=tags,
         user=user,
     )
 
 
-def page(cursor=None, limit=None, after=None, before=None, status=None, tags=None, ids=None,
-         end_to_end_ids=None, external_ids=None, user=None):
+def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None,
+         end_to_end_ids=None, external_ids=None, tags=None, user=None):
     """# Retrieve paged PixRequests
     Receive a list of up to 100 PixRequest objects previously created in the Stark Infra API and the cursor to the next page.
     Use this function instead of query if you want to manually page your requests.
@@ -156,11 +159,11 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, tags=Non
     - after [datetime.date or string, default None]: date filter for objects created after a specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "processing", "success", "failed"]
-    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - end_to_end_ids [list of strings, default None]: central bank's unique transaction IDs. ex: ["E79457883202101262140HHX553UPqeq", "E79457883202101262140HHX553UPxzx"]
     - external_ids [list of strings, default None]: url safe strings that must be unique among all your PixRequests. Duplicated external IDs will cause failures. By default, this parameter will block any PixRequests that repeats amount and receiver information on the same date. ex: ["my-internal-id-123456", "my-internal-id-654321"]
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - list of PixRequest objects with updated attributes
     - cursor to retrieve the next page of PixRequest objects
@@ -172,16 +175,16 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, tags=Non
         after=check_date(after),
         before=check_date(before),
         status=status,
-        tags=tags,
         ids=ids,
         end_to_end_ids=end_to_end_ids,
         external_ids=external_ids,
+        tags=tags,
         user=user,
     )
 
 
 def parse(content, signature, user=None):
-    """# Create single verified PixRequest object from a content string
+    """# Create a single verified PixRequest object from a content string
     Create a single PixRequest object from a content string received from a handler listening at the request url.
     If the provided digital signature does not check out with the StarkInfra public key, a
     starkinfra.error.InvalidSignatureError will be raised.
@@ -189,9 +192,38 @@ def parse(content, signature, user=None):
     - content [string]: response content from request received at user endpoint (not parsed)
     - signature [string]: base-64 digital signature received at response header "Digital-Signature"
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - Parsed PixRequest object
     """
+    request = parse_and_verify(
+        content=content,
+        signature=signature,
+        user=user,
+        resource=_resource
+    )
 
-    return parse_and_verify(content=content, signature=signature, user=user, resource=_resource)
+    request.fee = request.fee or 0
+    request.tags = request.tags or []
+    request.external_id = request.external_id or ""
+    request.description = request.description or ""
+    
+    return request
+
+
+def response(status, reason=None):
+    """# Helps you respond to a PixRequest authorization
+    ## Parameters (required):
+    - status [string]: response to the authorization. ex: "approved" or "denied"
+    ## Parameters (conditionally required):
+    - reason [string, default None]: denial reason. Options: "invalidAccountNumber", "blockedAccount", "accountClosed", "invalidAccountType", "invalidTransactionType", "taxIdMismatch", "invalidTaxId", "orderRejected", "reversalTimeExpired", "settlementFailed"
+    ## Return:
+    - Dumped JSON string that must be returned to us
+    """
+    params = {
+        "authorization": {
+            "status": status,
+            "reason": reason,
+        }
+    }
+    return dumps(api_json(params))
