@@ -1,7 +1,9 @@
-from ..utils import rest
-from ..utils.parse import parse_and_verify
+from json import dumps
+from starkcore.utils.api import api_json
 from starkcore.utils.resource import Resource
 from starkcore.utils.checks import check_datetime, check_date
+from ..utils import rest
+from ..utils.parse import parse_and_verify
 
 
 class PixReversal(Resource):
@@ -17,11 +19,10 @@ class PixReversal(Resource):
     - end_to_end_id [string]: central bank's unique transaction ID. ex: "E79457883202101262140HHX553UPqeq"
     - reason [string]: reason why the PixRequest is being reversed. Options are "bankError", "fraud", "chashierError", "customerRequest"
     ## Parameters (optional):
-    - tags [list of strings, default None]: list of strings for reference when searching for PixReversals. ex: ["employees", "monthly"]
+    - tags [list of strings, default []]: list of strings for reference when searching for PixReversals. ex: ["employees", "monthly"]
     ## Attributes (return-only):
-    - id [string]: unique id returned when the PixReversal is created. ex: "5656565656565656".
-    - return_id [string]: central bank's unique reversal transaction ID. ex: "D20018183202202030109X3OoBHG74wo".
-    - bank_code [string]: code of the bank institution in Brazil. ex: "20018183"
+    - id [string]: unique id returned when the PixReversal is created. ex: "5656565656565656"
+    - return_id [string]: central bank's unique reversal transaction ID. ex: "D20018183202202030109X3OoBHG74wo"
     - fee [string]: fee charged by this PixReversal. ex: 200 (= R$ 2.00)
     - status [string]: current PixReversal status. ex: "created", "processing", "success", "failed"
     - flow [string]: direction of money flow. ex: "in" or "out"
@@ -29,7 +30,7 @@ class PixReversal(Resource):
     - updated [datetime.datetime]: latest update datetime for the PixReversal. ex: datetime.datetime(2020, 3, 10, 10, 30, 0, 0)
     """
 
-    def __init__(self, amount, external_id, end_to_end_id, reason, tags=None, id=None, return_id=None, bank_code=None,
+    def __init__(self, amount, external_id, end_to_end_id, reason, tags=None, id=None, return_id=None,
                  fee=None, status=None, flow=None, created=None, updated=None):
         Resource.__init__(self, id=id)
         
@@ -39,7 +40,6 @@ class PixReversal(Resource):
         self.reason = reason
         self.tags = tags
         self.return_id = return_id
-        self.bank_code = bank_code
         self.fee = fee
         self.status = status
         self.flow = flow
@@ -56,7 +56,7 @@ def create(reversals, user=None):
     ## Parameters (required):
     - reversals [list of PixReversal objects]: list of PixReversal objects to be created in the API
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - list of PixReversal objects with updated attributes
     """
@@ -69,15 +69,15 @@ def get(id, user=None):
     ## Parameters (required):
     - id [string]: object unique id. ex: "5656565656565656"
     ## Parameters (optional):
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - PixReversal object with updated attributes
     """
     return rest.get_id(resource=_resource, id=id, user=user)
 
 
-def query(limit=None, after=None, before=None, status=None, tags=None, ids=None, return_ids=None,
-          external_ids=None, user=None):
+def query(limit=None, after=None, before=None, status=None, ids=None, return_ids=None,
+          external_ids=None, tags=None, user=None):
     """# Retrieve PixReversals
     Receive a generator of PixReversal objects previously created in the Stark Infra API
     ## Parameters (optional):
@@ -85,11 +85,11 @@ def query(limit=None, after=None, before=None, status=None, tags=None, ids=None,
     - after [datetime.date or string, default None]: date filter for objects created after a specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "processing", "success", "failed"]
-    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - return_ids [list of strings, default None]: central bank's unique reversal transaction IDs. ex: ["D20018183202202030109X3OoBHG74wo", "D20018183202202030109X3OoBHG72rd"].
     - external_ids [list of strings, default None]: url safe strings that must be unique among all your PixReversals. Duplicated external IDs will cause failures. By default, this parameter will block any PixReversal that repeats amount and receiver information on the same date. ex: ["my-internal-id-123456", "my-internal-id-654321"]
-    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
+    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
+    - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call.
     ## Return:
     - generator of PixReversal objects with updated attributes
     """
@@ -100,16 +100,16 @@ def query(limit=None, after=None, before=None, status=None, tags=None, ids=None,
         after=check_date(after),
         before=check_date(before),
         status=status,
-        tags=tags,
         ids=ids,
         return_ids=return_ids,
         external_ids=external_ids,
+        tags=tags,
         user=user,
     )
 
 
-def page(cursor=None, limit=None, after=None, before=None, status=None, tags=None, ids=None,
-         return_ids=None, external_ids=None, user=None):
+def page(cursor=None, limit=None, after=None, before=None, status=None, ids=None,
+         return_ids=None, external_ids=None, tags=None, user=None):
     """# Retrieve paged PixReversals
     Receive a list of up to 100 PixReversal objects previously created in the Stark Infra API and the cursor to the next page.
     Use this function instead of query if you want to manually page your reversals.
@@ -119,10 +119,10 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, tags=Non
     - after [datetime.date or string, default None]: date filter for objects created after a specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created before a specified date. ex: datetime.date(2020, 3, 10)
     - status [list of strings, default None]: filter for status of retrieved objects. ex: ["created", "processing", "success", "failed"]
-    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - return_ids [list of strings, default None]: central bank's unique reversal transaction ID. ex: ["D20018183202202030109X3OoBHG74wo", "D20018183202202030109X3OoBHG72rd"].
     - external_ids [list of strings, default None]: url safe string that must be unique among all your PixReversals. Duplicated external IDs will cause failures. By default, this parameter will block any PixReversal that repeats amount and receiver information on the same date. ex: ["my-internal-id-123456", "my-internal-id-654321"]
+    - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
     ## Return:
     - list of PixReversal objects with updated attributes
@@ -135,16 +135,16 @@ def page(cursor=None, limit=None, after=None, before=None, status=None, tags=Non
         after=check_date(after),
         before=check_date(before),
         status=status,
-        tags=tags,
         ids=ids,
         return_ids=return_ids,
         external_ids=external_ids,
+        tags=tags,
         user=user,
     )
 
 
 def parse(content, signature, user=None):
-    """# Create single verified PixReversal object from a content string
+    """# Create a single verified PixReversal object from a content string
     Create a single PixReversal object from a content string received from a handler listening at the reversal url.
     If the provided digital signature does not check out with the StarkInfra public key, a
     starkinfra.error.InvalidSignatureError will be raised.
@@ -156,5 +156,34 @@ def parse(content, signature, user=None):
     ## Return:
     - Parsed PixReversal object
     """
+    request = parse_and_verify(
+        content=content,
+        signature=signature,
+        user=user,
+        resource=_resource
+    )
 
-    return parse_and_verify(content=content, signature=signature, user=user, resource=_resource)
+    request.fee = request.fee or 0
+    request.tags = request.tags or []
+    request.external_id = request.external_id or ""
+    request.description = request.description or ""
+    
+    return request
+
+
+def response(status, reason=None):
+    """# Helps you respond to a PixReversal authorization
+    ## Parameters (required):
+    - status [string]: response to the authorization. ex: "approved" or "denied"
+    ## Parameters (conditionally required):
+    - reason [string, default None]: denial reason. Options: "invalidAccountNumber", "blockedAccount", "accountClosed", "invalidAccountType", "invalidTransactionType", "taxIdMismatch", "invalidTaxId", "orderRejected", "reversalTimeExpired", "settlementFailed"
+    ## Return:
+    - Dumped JSON string that must be returned to us
+    """
+    params = {
+        "authorization": {
+            "status": status,
+            "reason": reason,
+        }
+    }
+    return dumps(api_json(params))
